var searchData=
[
  ['ic_0',['Ic',['../classgko_1_1factorization_1_1Ic.html',1,'gko::factorization::Ic&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Ic.html',1,'gko::preconditioner::Ic&lt; LSolverTypeOrValueType, IndexType &gt;']]],
  ['ic_3c_20lsolvertypeorvaluetype_2c_20indextype_20_3e_1',['Ic&lt; LSolverTypeOrValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Ic.html',1,'gko::preconditioner']]],
  ['identity_2',['Identity',['../classgko_1_1batch_1_1matrix_1_1Identity.html',1,'gko::batch::matrix::Identity&lt; ValueType &gt;'],['../classgko_1_1matrix_1_1Identity.html',1,'gko::matrix::Identity&lt; ValueType &gt;']]],
  ['identity_3c_20valuetype_20_3e_3',['Identity&lt; ValueType &gt;',['../classgko_1_1matrix_1_1Identity.html',1,'gko::matrix']]],
  ['identityfactory_4',['IdentityFactory',['../classgko_1_1matrix_1_1IdentityFactory.html',1,'gko::matrix']]],
  ['idr_5',['Idr',['../classgko_1_1solver_1_1Idr.html',1,'gko::solver']]],
  ['idr_3c_20valuetype_20_3e_6',['Idr&lt; ValueType &gt;',['../classgko_1_1solver_1_1Idr.html',1,'gko::solver']]],
  ['ilu_7',['Ilu',['../classgko_1_1factorization_1_1Ilu.html',1,'gko::factorization::Ilu&lt; ValueType, IndexType &gt;'],['../classgko_1_1preconditioner_1_1Ilu.html',1,'gko::preconditioner::Ilu&lt; LSolverTypeOrValueType, USolverTypeOrValueType, ReverseApply, IndexType &gt;']]],
  ['ilu_3c_20gko_3a_3adetail_3a_3atransposed_5ftype_3c_20usolvertypeorvaluetype_20_3e_2c_20gko_3a_3adetail_3a_3atransposed_5ftype_3c_20lsolvertypeorvaluetype_20_3e_2c_20reverseapply_2c_20indextype_20_3e_8',['Ilu&lt; gko::detail::transposed_type&lt; USolverTypeOrValueType &gt;, gko::detail::transposed_type&lt; LSolverTypeOrValueType &gt;, ReverseApply, IndexType &gt;',['../classgko_1_1preconditioner_1_1Ilu.html',1,'gko::preconditioner']]],
  ['imag_5foperation_9',['imag_operation',['../structgko_1_1accessor_1_1imag__operation.html',1,'gko::accessor']]],
  ['imag_5foperaton_10',['imag_operaton',['../structgko_1_1accessor_1_1imag__operaton.html',1,'gko::accessor']]],
  ['imbalance_5fbounded_5flimit_11',['imbalance_bounded_limit',['../classgko_1_1matrix_1_1Hybrid_1_1imbalance__bounded__limit.html',1,'gko::matrix::Hybrid']]],
  ['imbalance_5flimit_12',['imbalance_limit',['../classgko_1_1matrix_1_1Hybrid_1_1imbalance__limit.html',1,'gko::matrix::Hybrid']]],
  ['implicitresidualnorm_13',['ImplicitResidualNorm',['../classgko_1_1stop_1_1ImplicitResidualNorm.html',1,'gko::stop']]],
  ['index_5fmap_14',['index_map',['../classgko_1_1experimental_1_1distributed_1_1index__map.html',1,'gko::experimental::distributed']]],
  ['index_5fmap_3c_20local_5findex_5ftype_2c_20global_5findex_5ftype_20_3e_15',['index_map&lt; local_index_type, global_index_type &gt;',['../classgko_1_1experimental_1_1distributed_1_1index__map.html',1,'gko::experimental::distributed']]],
  ['index_5fset_16',['index_set',['../classgko_1_1index__set.html',1,'gko']]],
  ['invalidstateerror_17',['InvalidStateError',['../classgko_1_1InvalidStateError.html',1,'gko']]],
  ['isai_18',['Isai',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['isai_3c_20isai_5ftype_3a_3ageneral_2c_20valuetype_2c_20indextype_20_3e_19',['Isai&lt; isai_type::general, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['isai_3c_20isai_5ftype_3a_3alower_2c_20valuetype_2c_20indextype_20_3e_20',['Isai&lt; isai_type::lower, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['isai_3c_20isai_5ftype_3a_3aspd_2c_20valuetype_2c_20indextype_20_3e_21',['Isai&lt; isai_type::spd, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['isai_3c_20isai_5ftype_3a_3aupper_2c_20valuetype_2c_20indextype_20_3e_22',['Isai&lt; isai_type::upper, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['isai_3c_20isaitype_3d_3disai_5ftype_3a_3ageneral_20_3f_20isai_5ftype_3a_3ageneral_20_3aisaitype_3d_3disai_5ftype_3a_3aspd_20_3f_20isai_5ftype_3a_3aspd_20_3aisaitype_3d_3disai_5ftype_3a_3alower_20_3f_20isai_5ftype_3a_3aupper_20_3aisai_5ftype_3a_3alower_2c_20valuetype_2c_20indextype_20_3e_23',['Isai&lt; IsaiType==isai_type::general ? isai_type::general :IsaiType==isai_type::spd ? isai_type::spd :IsaiType==isai_type::lower ? isai_type::upper :isai_type::lower, ValueType, IndexType &gt;',['../classgko_1_1preconditioner_1_1Isai.html',1,'gko::preconditioner']]],
  ['iteration_24',['Iteration',['../classgko_1_1stop_1_1Iteration.html',1,'gko::stop']]],
  ['iteration_5fcomplete_5fdata_25',['iteration_complete_data',['../structgko_1_1log_1_1iteration__complete__data.html',1,'gko::log']]],
  ['iterativebase_26',['IterativeBase',['../classgko_1_1solver_1_1IterativeBase.html',1,'gko::solver']]]
];
